=========
Changelog
=========

Version 0.4
===========

- Add support for GLDAS version 2.1
- Compress files during reshuffling.

Version 0.3
===========

- Fix download with new URL
- Only download grb and xml files

Version 0.2
===========

- Fix Python 3 bug when iterating over multiple images.
- Add reshuffling to time series format and reading of time series.

Version 0.1
===========

- First release. Support for Downloading and reading GLDAS Noah v1 0.25 degree
  data.
